@@ -18,6 +18,7 @@ class Cache(objects.Object):
 		self.assign({
 			"path":path,
 		})
+		self.fp = self.file_path = FilePath(self.path)
 	def set(self, data=None, group=None, id=None, format="str"):
 		if id == None:
 			data_path = f"{self.path}/{group}"
@@ -87,12 +88,13 @@ class WebServer(objects.Thread):
 		self.tag = self.id.replace(" ","_")
 		try: self.log_level
 		except: self.log_level = 0
+	# cache functions.
 	def set(self, group=None, id=None, data=None, timeout=3):
 		encoded = urllib.parse.urlencode({
-			"group":group,
-			"id":id,
+			"group":group.replace(" ","_"),
+			"id":id.replace(" ","_"),
 			"data":data,
-			"token":self.token(),
+			"token":self.token,
 			"cache":self.__cache__.path,
 			"cache_id":self.id,
 		})
@@ -107,9 +109,9 @@ class WebServer(objects.Thread):
 		return r3sponse.safe_response(response)
 	def get(self, group=None, id=None, timeout=3):
 		encoded = urllib.parse.urlencode({
-			"group":group,
-			"id":id,
-			"token":self.token(),
+			"group":group.replace(" ","_"),
+			"id":id.replace(" ","_"),
+			"token":self.token,
 			"cache":self.__cache__.path,
 			"cache_id":self.id,
 		})
@@ -122,6 +124,7 @@ class WebServer(objects.Thread):
 		except:
 			return r3sponse.error(f"Failed to serialize {response}: {response.text}")
 		return r3sponse.safe_response(response)
+	# flask app.
 	def app(self):
 		app = flask.Flask(__name__)
 		cli = sys.modules['flask.cli']
@@ -177,28 +180,14 @@ class WebServer(objects.Thread):
 		#self.process = multiprocessing.Process(target=app.run, args=(self, app, self.host,self.port,))
 		#self.process.start()
 		app.run(host=self.host, port=self.port)
-	def token(self):
-		if random.randrange(1, 100) <= 5: 
-			self.__cache__.set(group=self.id, id="token", data=String().generate(length=64, digits=True, capitalize=True))
-		return self.__cache__.get(group=self.id, id="token")
-	def running(self, timeout=3):
-		encoded = urllib.parse.urlencode({
-			"token":self.token(),
-			"cache":self.__cache__.path,
-			"cache_id":self.id,
-		})
-		try:
-			requests.get(f'http://{self.host}:{self.port}/active?{encoded}', timeout=timeout)
-			return True
-		except requests.exceptions.ConnectionError:
-			return False
+	# control functions.
 	def run(self):
 		self.__cache__.set(group=self.id, id="daemon", data="*running*")
 		self.__cache__.set(group=self.id, id="token", data=String().generate(length=64, digits=True, capitalize=True))
 		self.app()
 		self.__cache__.set(group=self.id, id="daemon", data="*stopped*")
 	def fork(self, timeout=15, sleeptime=1):
-		if self.running():
+		if self.running:
 			return r3sponse.error(f"The {self.id} is already running.")
 		if self.log_level <= 0:
 			print(f"Starting the {self.id}.")
@@ -207,13 +196,13 @@ class WebServer(objects.Thread):
 		for i in ["__cache__","cache",]:
 			del serialized[i]
 		serialized = json.dumps(self.__serialize__(serialized, safe=True),indent=0)
-		command = ["python3", f"{SOURCE_PATH}classes/cache/fork.py", "--serialized", f"'{serialized}'", "--syst3m-webserver-tag", self.tag]
+		command = [defaults.vars.python3, f"{SOURCE_PATH}classes/cache/fork.py", "--serialized", f"'{serialized}'", "--syst3m-webserver-tag", self.tag]
 		if self.log_level < 0:
 			command += [ "2>", "/dev/null"]
 		p = subprocess.Popen(command)
 		success = False
 		for i in range(int(timeout/sleeptime)):
-			if self.running():
+			if self.running:
 				success = True
 				break
 			time.sleep(sleeptime)
@@ -222,7 +211,7 @@ class WebServer(objects.Thread):
 		else:
 			return r3sponse.error(f"The {self.id} is already running.")
 	def stop(self):
-		if not self.running(): 
+		if not self.running: 
 			return r3sponse.error(f"The {self.id} is not running.")
 		processes = processes(includes=f"--syst3m-webserver-tag {self.tag}")
 		if not processes.success: return response
@@ -233,6 +222,47 @@ class WebServer(objects.Thread):
 				response = kill(pid=pid)
 				if not response.success: return response
 		return r3sponse.error(f"Successfully stopped the {self.id}.")
+	# threading functions.
+	def start_thread(self, thread, group="daemons", id=None):
+		response = self.set(group=group, id=id, data=thread)
+		if not response.success: return response
+		respose = thread.start()
+		if response != None:
+			try: success = bool(response["success"])
+			except: success = True
+			if not success: return response
+		return r3sponse.success(f"Successfully started thread [{thread}].")
+	def get_thread(self, group="daemos", id=None):
+		response = self.get(group=group, id=id)
+		if not response.success: 
+			if "There is no data cached for" in response.error:
+				return r3sponse.error(f"There is no thread cached for (group: {group}), (id: {id}).")
+			else: return response
+		thread = response.data
+		return r3sponse.success(f"Successfully retrieved thread [{thread}].", {
+			"thread":thread,
+		})
+	# properties.
+	@property
+	def token(self):
+		if random.randrange(1, 100) <= 5: 
+			self.__cache__.set(group=self.id, id="token", data=String().generate(length=64, digits=True, capitalize=True))
+		return self.__cache__.get(group=self.id, id="token")
+	@property
+	def running(self):
+		return self.__running__()
+	def __running__(self, timeout=3):
+		encoded = urllib.parse.urlencode({
+			"token":self.token,
+			"cache":self.__cache__.path,
+			"cache_id":self.id,
+		})
+		try:
+			requests.get(f'http://{self.host}:{self.port}/active?{encoded}', timeout=timeout)
+			return True
+		except requests.exceptions.ConnectionError:
+			return False
+	# system functions.
 	def __serialize__(self, dict, safe=False):
 		for key in list(dict.keys()):
 			value = dict[key]
