@@ -81,7 +81,7 @@ try:
 except ImportError as e:
 	import os
 	if os.path.exists("/usr/bin/pip3"): 
-		os.system(f"/usr/bin/pip3 install -r {FilePath(__file__).base(back=3)}/requirements/requirements.txt --user {os.environ.get('USER')}")
+		os.system(f"/usr/bin/pip3 install -r {FilePath(__file__).base(back=3)}/requirements/requirements.pip --user {os.environ.get('USER')}")
 	else:
 		os.system(f"pip3 install -r {FilePath(__file__).base(back=3)}/requirements/requirements.pip")
 
@@ -96,10 +96,6 @@ except ImportError as e:
 # imports.
 from r3sponse import ResponseObject
 
-# version.
-try: version = Files.load(f"{SOURCE_PATH}/.version")
-except: version = "unkown"
-
 # universal variables.
 USER = os.environ.get("USER")
 OWNER = os.environ.get("USER")
