@@ -3,7 +3,7 @@
 
 # imports.
 from syst3m.classes.config import *
-from syst3m.classes import utils
+from syst3m.classes import utils, console
 from syst3m.classes.color import color, symbol
 
 """
@@ -61,17 +61,15 @@ class User(object):
 
 		# handle linux.
 		if OS in ["linux"]:
-			#self.console.execute("sudo useradd -s /bin/bash -d {home_directory} -m {username} # for ubuntu".format(
 			# ubuntu.
-			output = utils.__execute__(
-				command=["sudo", "useradd", "-s", "/bin/bash", "-m", self.username],)
+			output = console.execute(f"sudo useradd -s /bin/bash -m {self.username}")
 
 			# success.
 			if output == "":
 				return r3sponse.success(f"Successfully created user [{self.username}].")
 
 			else:
-				return r3sponse.error(String(output.replace("useradd: ", "").replace("\n", ". ")).capitalized_word())
+				return r3sponse.error(String(str(output).replace("useradd: ", "").replace("\n", ". ")).capitalized_word())
 
 		# handle macos.
 		elif OS in ["macos"]:
@@ -143,7 +141,7 @@ class User(object):
 		if OS in ["linux"]:
 
 			# get output.
-			output = utils.__execute_script__(f"export HISTIGNORE='*sudo -S*' && echo '{password}\n{password}\n' | sudo -S -k sudo passwd {self.username}")
+			output = console.execute(f"export HISTIGNORE='*sudo -S*' && echo '{password}\n{password}\n' | sudo -S -k sudo passwd {self.username}")
 			
 			# success.
 			if "password updated successfully" in output:
@@ -151,6 +149,7 @@ class User(object):
 
 			# fail.
 			else:
+				print(output)
 				return r3sponse.error(f"Failed to edit the password of user [{self.username}].")
 
 		# handle macos.
@@ -238,15 +237,14 @@ class Group(object):
 
 		# handle linux.
 		if OS in ["linux"]:
-			output = utils.__execute__(
-				command=["sudo", "groupadd", self.name],)
+			output = console.execute(f"sudo groupadd {self.name}",)
 
 			# success.
 			if output == "":
 				return r3sponse.success(f"Successfully created group [{self.name}].")
 
 			else:
-				return r3sponse.error(String(output.replace("groupadd: ", "").replace("\n", ". ")).capitalized_word())
+				return r3sponse.error(String(str(output).replace("groupadd: ", "").replace("\n", ". ")).capitalized_word())
 
 		# handle macos.
 		elif OS in ["macos"]:
@@ -339,10 +337,9 @@ class Group(object):
 		# handle linux.
 		if OS in ["linux"]:
 			for user in users:
-				output = utils.__execute__(
-					command=["sudo", "deluser", user, self.name],)
+				output = console.execute(f"sudo deluser {user} {self.name}")
 				if output != "":
-					return r3sponse.error(String(output.replace("deluser: ", "").replace("\n", ". ")).capitalized_word())
+					return r3sponse.error(String(str(output).replace("deluser: ", "").replace("\n", ". ")).capitalized_word())
 
 		# handle macos.
 		elif OS in ["macos"]:
@@ -368,7 +365,7 @@ class Group(object):
 				output = console.execute(f"sudo usermod -a -G {self.name} {user}")
 				if not output.success: return output
 				if str(output) != "":
-					return r3sponse.error(String(output.replace("usermod: ", "").replace("\n", ". ")).capitalized_word())
+					return r3sponse.error(String(str(output).replace("usermod: ", "").replace("\n", ". ")).capitalized_word())
 
 		# handle macos.
 		elif OS in ["macos"]:
